@@ -13,6 +13,7 @@ from nlp_tools.generators import CorpusGenerator
 from nlp_tools.logger import logger
 from nlp_tools.processors.abc_label_processor import ABCLabelProcessor
 from nlp_tools.utils.ner_utils import get_entities
+from nlp_tools.utils.segment_utils import get_words
 from tensorflow.keras.utils import to_categorical
 
 
@@ -173,18 +174,39 @@ class CascadeSentenceLabelProcessor(ABCLabelProcessor):
         目前采用第一种
         """
         std_labels = []
-        for index, bmeo_line in enumerate(segment_labels_id):
-            bmeo_attr_label = []
-            attr_line = attr_labels_id[index]
-            for item in list(zip(bmeo_line, attr_line)):
-                bmeo_id = item[0]
-                attr_id = item[1]
-                if bmeo_id == "O":
-                    bmeo_attr = "O"
-                else:
-                    bmeo_attr = bmeo_id + "-" + attr_id
-                bmeo_attr_label.append(bmeo_attr)
-            std_labels.append(bmeo_attr_label)
+
+        # way one
+        # for index, bmeo_line in enumerate(segment_labels_id):
+        #     bmeo_attr_label = []
+        #     attr_line = attr_labels_id[index]
+        #     for item in list(zip(bmeo_line, attr_line)):
+        #         bmeo_id = item[0]
+        #         attr_id = item[1]
+        #         if bmeo_id == "O":
+        #             bmeo_attr = "O"
+        #         else:
+        #             bmeo_attr = bmeo_id + "-" + attr_id
+        #         bmeo_attr_label.append(bmeo_attr)
+        #     std_labels.append(bmeo_attr_label)
+
+        # way two
+        std_labels = []
+        for segments,attrs in zip(segment_labels_id,attr_labels_id):
+            words = get_words(segments)
+            labels = ['O'] * len(attrs)
+            for word in words:
+                word_label = attrs[word[1]]
+                labels[word[0]] = "B-" +word_label
+                for idx in range(word[0]+1,word[1]+1):
+                    labels[idx] = "I-" + word_label
+            std_labels.append(labels)
+        return std_labels
+
+
+
+
+
+
         # print("std labels")
         # print(std_labels)
         return std_labels
