@@ -10,6 +10,7 @@ from nlp_tools.logger import logger
 from nlp_tools.layers.pool_layer import PoolerInputLayer
 
 from tensorflow.keras.metrics import sparse_categorical_accuracy
+from nlp_tools.layers.non_masking_layer import MaskingSaverLayer
 
 
 
@@ -37,10 +38,13 @@ class Cascade_Model(ABCLabelingModel):
         segment_output_dim = len(self.label_processor.segmetn_idx_2_label.items())
 
         label_output_dim = self.label_processor.vocab_size
+        self.mask_save_layer = MaskingSaverLayer()
 
         config = self.hyper_parameters
         embed_model = self.embedding.embed_model
 
+
+
         crf = KConditionalRandomField()
         layer_stack = [
             L.Bidirectional(L.LSTM(**config['layer_blstm']), name='layer_blstm'),
@@ -48,12 +52,14 @@ class Cascade_Model(ABCLabelingModel):
         ]
 
         tensor = embed_model.output
-        for layer in layer_stack:
-            tensor = layer(tensor)
+        # for layer in layer_stack:
+        #     tensor = layer(tensor)
+        tensor = self.mask_save_layer(tensor)
 
 
         # crf层输出
-        segment_output = L.Dense(segment_output_dim, **config['layer_time_distributed'])(tensor)
+        segment_output = L.Dense(128,activation='tanh')(tensor)
+        segment_output = L.Dense(segment_output_dim, **config['layer_time_distributed'])(segment_output)
         crf_output = crf(segment_output)
 
 
@@ -62,18 +68,31 @@ class Cascade_Model(ABCLabelingModel):
 
         # label predict输出
         #predict_label_embedding = L.Dense(64)(crf_output)
-        # logit_classify = embed_model.output
+        #logit_classify = embed_model.output
         # for layer in layer_stack:
         #     logit_classify = layer(logit_classify)
+        from bert4keras.layers import LayerNormalization
 
-        logits_label = PoolerInputLayer(128,label_output_dim)([tensor,crf_output])
-        #logits_label = L.Dense(label_output_dim, **config['layer_time_distributed'])(tf.concat([logit_classify,crf_output],axis=-1))
-        label_predict_output = tf.nn.softmax(logits_label)
+        output = self.embedding.embed_model.layers[-2].get_output_at(-1)
+
+        #logits_label = LayerNormalization(conditional=True)([output, crf_output])
+
+        logits_label = PoolerInputLayer(128,label_output_dim)([embed_model.output,crf_output])
+        #input = tf.keras.layers.Concatenate()([embed_model.output,crf_output])
+        #x = tf.keras.layers.Dense(128)(input)
+        #logits_label = L.Dense(label_output_dim, **config['layer_time_distributed1'])(logits_label)
+        logits_label = L.Bidirectional(L.LSTM(**config['layer_blstm']), name='layer_blstm2')(logits_label)
+        logits_label = L.Dense(label_output_dim, **config['layer_time_distributed'])(logits_label)
+        #label_predict_output = tf.nn.softmax(logits_label,axis=-1)
+
+        crf2 = KConditionalRandomField()
+        crf_classify_output = crf2(logits_label)
 
 
-        self.tf_model = keras.Model(embed_model.inputs, [crf_output,label_predict_output])
+        self.tf_model = keras.Model(embed_model.inputs, [crf_output,crf_classify_output])
         #self.tf_model = keras.Model(embed_model.inputs, crf_output)
         self.crf_layer = crf
+        self.crf_layer2 = crf2
 
     def compile_model(self,
                       loss: Any = None,
@@ -82,9 +101,12 @@ class Cascade_Model(ABCLabelingModel):
                       **kwargs: Any) -> None:
 
         if loss is None:
-            loss = [self.crf_layer.loss,self.cascade_label_cross_entropy]
+            from tensorflow_addons.losses import SigmoidFocalCrossEntropy
+            from tensorflow.keras.losses import SparseCategoricalCrossentropy
+            #self.mask_save_layer.set_loss_func(SparseCategoricalCrossentropy())
+            loss = [self.crf_layer.loss,self.crf_layer2.loss]
         if metrics is None:
-            metrics = [[self.crf_layer.accuracy],[sparse_categorical_accuracy]]
+            metrics = [[self.crf_layer.accuracy],[self.crf_layer2.accuracy]]
         super(Cascade_Model, self).compile_model(loss=loss,
                                                     optimizer=optimizer,
                                                     metrics=metrics,
